import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { cn } from "@/lib/utils";
import { Minus, Plus } from "lucide-react";
import { useTranslations } from "next-intl";



interface ProductQuantityProps {
	quantity: number;
	handleQuantityChange: (value: number) => void;
}

const ProductQuantity = ({ quantity, handleQuantityChange }: ProductQuantityProps) => {
	const t = useTranslations("Common");
	return (
		<div className={cn("flex items-center gap-4")}>
			<p className="text-custom-dark">{t("Quantity")}:</p>
			<div className="flex items-center gap-2">
				<Button
					variant="outline"
					size="icon"
					onClick={() => handleQuantityChange(quantity - 1)}
					disabled={quantity <= 1}
				>
					<Minus className="h-4 w-4" />
				</Button>
				<Input
					type="text"
					value={quantity}
					onChange={(e) => handleQuantityChange(Number(e.target.value))}
					className="w-20 text-center"
					min={1}
				/>
				<Button
					variant="outline"
					size="icon"
					onClick={() => handleQuantityChange(quantity + 1)}
				>
					<Plus className="h-4 w-4" />
				</Button>
			</div>
		</div>
	);
};

export default ProductQuantity; 